pub struct IrcMessage {
pub tags: HashMap<String, Option<String>>,
pub prefix: Option<String>,
pub command: String,
pub params: Vec<String>,
}Expand description
An IRC message with optional tags, prefix, command, and parameters
Fields
Message tags (IRCv3)
prefix: Option<String>Message prefix (source)
command: StringIRC command
params: Vec<String>Command parameters
Implementations
Sourceimpl IrcMessage
impl IrcMessage
Sourcepub fn with_params(self, params: Vec<String>) -> Self
pub fn with_params(self, params: Vec<String>) -> Self
Add parameters to the message
Sourcepub fn with_prefix(self, prefix: impl Into<String>) -> Self
pub fn with_prefix(self, prefix: impl Into<String>) -> Self
Add a prefix to the message
Sourcepub fn with_tag(self, key: impl Into<String>, value: Option<String>) -> Self
pub fn with_tag(self, key: impl Into<String>, value: Option<String>) -> Self
Add a tag to the message
Add multiple tags to the message
Sourcepub fn get_timestamp(&self) -> SystemTime
pub fn get_timestamp(&self) -> SystemTime
Extract server timestamp from message tags, fallback to current time
Sourcepub fn get_account(&self) -> Option<&str>
pub fn get_account(&self) -> Option<&str>
Get the account tag (if present)
Sourcepub fn is_message(&self) -> bool
pub fn is_message(&self) -> bool
Check if this is a PRIVMSG or NOTICE
Sourcepub fn is_channel_message(&self) -> bool
pub fn is_channel_message(&self) -> bool
Check if this is a channel message (target starts with # or &)